#ifndef _STL_TEST_H_
#define _STL_TEST_H_
//  An adapted ObjectSpace example for use with SGI STL
extern int accum1_test  ( int, char**);
extern int accum2_test  ( int, char**);
extern int adjdiff0_test  ( int, char**);
extern int adjdiff1_test  ( int, char**);
extern int adjdiff2_test  ( int, char**);
extern int adjfind0_test  ( int, char**);
extern int adjfind1_test  ( int, char**);
extern int adjfind2_test  ( int, char**);
extern int advance_test  ( int, char**);
extern int alg1_test  ( int, char**);
extern int alg2_test  ( int, char**);
extern int alg3_test  ( int, char**);
extern int alg4_test  ( int, char**);
extern int alg5_test  ( int, char**);
extern int bcompos1_test  ( int, char**);
extern int bcompos2_test  ( int, char**);
extern int bind1st1_test  ( int, char**);
extern int bind1st2_test  ( int, char**);
extern int bind2nd1_test  ( int, char**);
extern int bind2nd2_test  ( int, char**);
extern int binsert1_test  ( int, char**);
extern int binsert2_test  ( int, char**);
extern int binsrch1_test  ( int, char**);
extern int binsrch2_test  ( int, char**);
extern int bnegate1_test  ( int, char**);
extern int bnegate2_test  ( int, char**);
extern int bvec1_test  ( int, char**);
extern int copy1_test  ( int, char**);
extern int copy2_test  ( int, char**);
extern int copy3_test  ( int, char**);
extern int copy4_test  ( int, char**);
extern int copyb_test  ( int, char**);
extern int copyb0_test  ( int, char**);
extern int count0_test  ( int, char**);
extern int count1_test  ( int, char**);
extern int countif1_test  ( int, char**);
extern int deque1_test  ( int, char**);
extern int divides_test  ( int, char**);
extern int eqlrnge0_test  ( int, char**);
extern int eqlrnge1_test  ( int, char**);
extern int eqlrnge2_test  ( int, char**);
extern int equal0_test  ( int, char**);
extern int equal1_test  ( int, char**);
extern int equal2_test  ( int, char**);
extern int equalto_test  ( int, char**);
extern int error1_test  ( int, char**);
extern int fill1_test  ( int, char**);
extern int filln1_test  ( int, char**);
extern int find0_test  ( int, char**);
extern int find1_test  ( int, char**);
extern int findif0_test  ( int, char**);
extern int findif1_test  ( int, char**);
extern int finsert1_test  ( int, char**);
extern int finsert2_test  ( int, char**);
extern int foreach0_test  ( int, char**);
extern int foreach1_test  ( int, char**);
extern int func1_test  ( int, char**);
extern int func2_test  ( int, char**);
extern int func3_test  ( int, char**);
extern int gener1_test  ( int, char**);
extern int gener2_test  ( int, char**);
extern int genern1_test  ( int, char**);
extern int genern2_test  ( int, char**);
extern int greateq_test  ( int, char**);
extern int greater_test  ( int, char**);
extern int incl0_test  ( int, char**);
extern int incl1_test  ( int, char**);
extern int incl2_test  ( int, char**);
extern int inplmrg1_test  ( int, char**);
extern int inplmrg2_test  ( int, char**);
extern int inrprod0_test  ( int, char**);
extern int inrprod1_test  ( int, char**);
extern int inrprod2_test  ( int, char**);
extern int insert1_test  ( int, char**);
extern int insert2_test  ( int, char**);
extern int iota1_test  ( int, char**);
extern int istmit1_test  ( int, char**);
extern int iter1_test  ( int, char**);
extern int iter2_test  ( int, char**);
extern int iter3_test  ( int, char**);
extern int iter4_test  ( int, char**);
extern int iterswp0_test  ( int, char**);
extern int iterswp1_test  ( int, char**);
extern int less_test  ( int, char**);
extern int lesseq_test  ( int, char**);
extern int lexcmp1_test  ( int, char**);
extern int lexcmp2_test  ( int, char**);
extern int list1_test  ( int, char**);
extern int list2_test  ( int, char**);
extern int list3_test  ( int, char**);
extern int list4_test  ( int, char**);
extern int logicand_test  ( int, char**);
extern int logicnot_test  ( int, char**);
extern int logicor_test  ( int, char**);
extern int lwrbnd1_test  ( int, char**);
extern int lwrbnd2_test  ( int, char**);
extern int map1_test  ( int, char**);
extern int max1_test  ( int, char**);
extern int max2_test  ( int, char**);
extern int maxelem1_test  ( int, char**);
extern int maxelem2_test  ( int, char**);
extern int merge0_test  ( int, char**);
extern int merge1_test  ( int, char**);
extern int merge2_test  ( int, char**);
extern int min1_test  ( int, char**);
extern int min2_test  ( int, char**);
extern int minelem1_test  ( int, char**);
extern int minelem2_test  ( int, char**);
extern int minus_test  ( int, char**);
extern int mismtch0_test  ( int, char**);
extern int mismtch1_test  ( int, char**);
extern int mismtch2_test  ( int, char**);
extern int mkheap0_test  ( int, char**);
extern int mkheap1_test  ( int, char**);
extern int mmap1_test  ( int, char**);
extern int mmap2_test  ( int, char**);
extern int modulus_test  ( int, char**);
extern int mset1_test  ( int, char**);
extern int mset3_test  ( int, char**);
extern int mset4_test  ( int, char**);
extern int mset5_test  ( int, char**);
extern int negate_test  ( int, char**);
extern int nequal_test  ( int, char**);
extern int nextprm0_test  ( int, char**);
extern int nextprm1_test  ( int, char**);
extern int nextprm2_test  ( int, char**);
extern int nthelem0_test  ( int, char**);
extern int nthelem1_test  ( int, char**);
extern int nthelem2_test  ( int, char**);
extern int ostmit_test  ( int, char**);
extern int pair0_test  ( int, char**);
extern int pair1_test  ( int, char**);
extern int pair2_test  ( int, char**);
extern int parsrt0_test  ( int, char**);
extern int parsrt1_test  ( int, char**);
extern int parsrt2_test  ( int, char**);
extern int parsrtc0_test  ( int, char**);
extern int parsrtc1_test  ( int, char**);
extern int parsrtc2_test  ( int, char**);
extern int partsrt0_test  ( int, char**);
extern int partsum0_test  ( int, char**);
extern int partsum1_test  ( int, char**);
extern int partsum2_test  ( int, char**);
extern int pheap1_test  ( int, char**);
extern int pheap2_test  ( int, char**);
extern int plus_test  ( int, char**);
extern int pqueue1_test  ( int, char**);
extern int prevprm0_test  ( int, char**);
extern int prevprm1_test  ( int, char**);
extern int prevprm2_test  ( int, char**);
extern int ptition0_test  ( int, char**);
extern int ptition1_test  ( int, char**);
extern int ptrbinf1_test  ( int, char**);
extern int ptrbinf2_test  ( int, char**);
extern int ptrunf1_test  ( int, char**);
extern int ptrunf2_test  ( int, char**);
extern int queue1_test  ( int, char**);
extern int rawiter_test  ( int, char**);
extern int remcopy1_test  ( int, char**);
extern int remcpif1_test  ( int, char**);
extern int remif1_test  ( int, char**);
extern int remove1_test  ( int, char**);
extern int repcpif1_test  ( int, char**);
extern int replace0_test  ( int, char**);
extern int replace1_test  ( int, char**);
extern int replcpy1_test  ( int, char**);
extern int replif1_test  ( int, char**);
extern int revbit1_test  ( int, char**);
extern int revbit2_test  ( int, char**);
extern int revcopy1_test  ( int, char**);
extern int reverse1_test  ( int, char**);
extern int reviter1_test  ( int, char**);
extern int reviter2_test  ( int, char**);
extern int rndshuf0_test  ( int, char**);
extern int rndshuf1_test  ( int, char**);
extern int rndshuf2_test  ( int, char**);
extern int rotate0_test  ( int, char**);
extern int rotate1_test  ( int, char**);
extern int rotcopy0_test  ( int, char**);
extern int rotcopy1_test  ( int, char**);
extern int search0_test  ( int, char**);
extern int search1_test  ( int, char**);
extern int search2_test  ( int, char**);
extern int set1_test  ( int, char**);
extern int set2_test  ( int, char**);
extern int setdiff0_test  ( int, char**);
extern int setdiff1_test  ( int, char**);
extern int setdiff2_test  ( int, char**);
extern int setintr0_test  ( int, char**);
extern int setintr1_test  ( int, char**);
extern int setintr2_test  ( int, char**);
extern int setsymd0_test  ( int, char**);
extern int setsymd1_test  ( int, char**);
extern int setsymd2_test  ( int, char**);
extern int setunon0_test  ( int, char**);
extern int setunon1_test  ( int, char**);
extern int setunon2_test  ( int, char**);
extern int single_test  ( int, char**);
extern int sort1_test  ( int, char**);
extern int sort2_test  ( int, char**);
extern int stack1_test  ( int, char**);
extern int stack2_test  ( int, char**);
extern int stat_test  ( int, char**);
extern int stblptn0_test  ( int, char**);
extern int stblptn1_test  ( int, char**);
extern int stblsrt1_test  ( int, char**);
extern int stblsrt2_test  ( int, char**);
extern int swap1_test  ( int, char**);
extern int swprnge1_test  ( int, char**);
extern int times_test  ( int, char**);
extern int trnsfrm1_test  ( int, char**);
extern int trnsfrm2_test  ( int, char**);
extern int ucompos1_test  ( int, char**);
extern int ucompos2_test  ( int, char**);
extern int unegate1_test  ( int, char**);
extern int unegate2_test  ( int, char**);
extern int uniqcpy1_test  ( int, char**);
extern int uniqcpy2_test  ( int, char**);
extern int unique1_test  ( int, char**);
extern int unique2_test  ( int, char**);
extern int uprbnd1_test  ( int, char**);
extern int uprbnd2_test  ( int, char**);
extern int vec1_test  ( int, char**);
extern int vec2_test  ( int, char**);
extern int vec3_test  ( int, char**);
extern int vec4_test  ( int, char**);
extern int vec5_test  ( int, char**);
extern int vec6_test  ( int, char**);
extern int vec7_test  ( int, char**);
extern int vec8_test  ( int, char**);
extern int hmap1_test  ( int, char**);
extern int hmmap1_test  ( int, char**);
extern int hset2_test  ( int, char**);
extern int hmset1_test  ( int, char**);
extern int slist1_test (int, char**);
extern int string1_test (int, char**);
extern int bitset1_test (int, char**);
#endif
